@@ -35,7 +35,6 @@ def void():
                 'https://googleweblight.com/i?u=' ,# Redirect using Googleweblight [ No warning ]  [ source: Google ]
                 'https://l.wl.co/l?u=',              # Open_redirect Whatsapp Business Account Profile website links. [ source:M.Anish]
                 'https://tor2web.onionsearchengine.com/index.php?q=', #Open_redirect in Proxy.[ No warning ][ source: M.Anish]
-                'https://proxy.torgateway.com/index.php?q=',  #Open_redirect.[ No warning ][ source: M.Anish ] 
                 'https://onionengine.com/url.php?u=',
                 'http://raspe.id.au/bypass/miniProxy.php?', #Open_redirect in proxy [ No warning ] [ Difficult to detect ]
                 'https://www.awin1.com/cread.php?awinmid=6798&awinaffid=673201&ued=', # [ No warning ]
@@ -43,16 +42,6 @@ def void():
                 'https://www.digit.in/flipkart/intermediate?url=', # [ Easy to detect ]
                 'https://adclick.g.doubleclick.net/pcs/click?xai=AKAOjstFA55hCSrFSTBDNko3225YAz6GkouTQlHjExWXRbT5OPMnSlE8Wh4LAVp-D7jWRr-LcKW0w-HH1g8lCVAK_eU-5azfUXfjqfTiHFOFWV9I8m2ZaGczGlov1iY8kMSnelCX-AHG6VYBmpcZJapT1XbdlOM3B9u9whYqpkxEpFLbkzwDao00-DL8JyS7UIxIApb_JHANRmtKLSuRcM8IWqFaP0cOc8n8jTedmwHc8oAw2MV2tRUaAnN3eaxaESpc8fovDeWslJ0A3duo5g46YzCYxQ8A56RI5MGcQw4TZj6TeWuj6jRjAe7g0X18--IBmztC1sUi6XuHkB1Ew-z_h9bv1XK-s_9L6zeDfQPtMsI3hOqp8T8545VdgCoElxs&sig=Cg0ArKJSzEpZ_YMvCKWCEAE&fbs_aeid=[gw_fbsaeid]&urlfix=1&adurl=', # [ No warning ]
                 'https://shop-links.co/link?publisher_slug=future&exclusive=1&u1=tomsguide-in-2620345246174741000&url=', # [ No warning ]
-                'https://www.womginx.gq/main/', # [ No warning ]
-                'https://wassupwomiwi.herokuapp.com/main/',
-                'https://womginx.arph.org/main/',
-                'https://wg.abcya.ga/main/',
-                'https://e.lexiapowerup.ga/main/',
-                'http://seelenotseelie.herokuapp.com/main/',
-                'https://elzxs.herokuapp.com/main/',
-                'https://kavenciwomginx.herokuapp.com/main/',
-                'https://back4app.herokuapp.com/main/',
-                'https://bananalearning.herokuapp.com/main/',
                 'https://meumundomaisdigital.com.br/wp-content/plugins/super-links/application/helpers/super-links-proxy.php?',
                 'http://media.mailadam.com/proxy/index.php?',
                 'http://f2pool.cam/index.php?',
